Name: xos-blcr
Version: 0.8.0
Release: %mkrel 2
Summary: Berkeley Lab Checkpoint/Restart for Linux
Url: http://ftg.lbl.gov/checkpoint

%define ksubrel 2xos
%define kernelvs 2.6.27.24
%define kflavor xos-smp
%define kflavordevel xos
%define kernelv kernel-%{kflavor}-%{kernelvs}-%{ksubrel}
%define kerneldir /usr/src/kernel-%{kflavordevel}-devel-%{kernelvs}-%{ksubrel}smp
%define modsubpkg modules_%kernelv
%define moduledir /lib/modules/%{kernelvs}-%{ksubrel}smp/extra
%define sysmap /boot/System.map-%kernelvs-%{ksubrel}smp
%define distname %{name}-%{version}

Group: System Environment/Base
License: GPLv2+
Source: blcr-%{version}.tar.gz
Patch0:	xos-blcr-%{version}.patch
BuildRoot: %{_tmppath}/buildroot-%{name}-%{version}
BuildRequires: perl sed
buildRequires: %kernelv
BuildRequires: kernel-%{kflavor}-devel-%kernelvs-%{ksubrel}
Prereq: /sbin/chkconfig
ExclusiveArch: i386 i486 i586 i686 athlon x86_64 ppc64
ExclusiveOs: Linux
Requires: %{name}-modules = %{version}-%{release}

%description
Berkeley Lab Checkpoint/Restart for Linux (BLCR)

This package implements system-level checkpointing of scientific applications
in a manner suitable for implementing preemption, migration and fault recovery
by a batch scheduler.

BLCR includes documented interfaces for a cooperating applications or
libraries to implement extensions to the checkpoint system, such as
consistent checkpointing of distributed MPI applications.
Using this package with an appropriate MPI implementation, the vast majority
of scientific applications which use MPI for communucation on Linux clusters
are checkpointable without any modifications to the application source code.

You must also install the %{name}-libs package and a %{name}-modules_* package
matching your kernel version.

%package libs
Group: System Environment/Libraries
Summary: Libraries for Berkeley Lab Checkpoint/Restart for Linux
License: LGPLv2+
Prereq: /sbin/ldconfig

%description libs
Runtime libraries for Berkeley Lab Checkpoint/Restart for Linux (BLCR)

%package devel
Requires: %{name}-libs = %{version}-%{release}
Group: Development/Libraries
Summary: Header and object files for Berkeley Lab Checkpoint/Restart for Linux
License: LGPLv2+

%description devel
Header and object files for Berkeley Lab Checkpoint/Restart for Linux
You must also install the %{name}-libs package.

# Kernel modules as a separate package
%package %{modsubpkg}
Group: System Environment/Kernel
Summary: Kernel modules for Berkeley Lab Checkpoint/Restart for Linux
Provides: %{name}-modules = %{version}-%{release}
Prereq: %{name} = %{version}
Requires: %{name} >= %{version}-%{release}
Requires: %kernelv

%description %{modsubpkg}
Kernel modules for Berkeley Lab Checkpoint/Restart for Linux (BLCR)
These kernel modules are built for Linux %{kernelv}.

You must also install the base %{name} package.

## testsuite as an additional package if configured in
%package testsuite
Group: System Environment/Base
Summary: Test suite for Berkeley Lab Checkpoint/Restart for Linux
License: GPLv2+
Prereq: %{name} = %{version}
%description testsuite
This package includes tests for Berkeley Lab Checkpoint/Restart for Linux


%prep
%setup -q -n blcr-%{version}
%patch0 -p1
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT

%build
%define _host_cpu %{_target_cpu}
%define _host %{_target}
%define _build_cpu %{_target_cpu}
%define _build %{_target}
./autogen.sh
#ln -s ../configure .

%configure --enable-testsuite \
 --with-vmlinux=/boot/vmlinuz-%kernelv \
 --with-system-map=%{sysmap} \
 --with-linux=%{kerneldir}

# Now build it
%make

%clean
rm -rf ${RPM_BUILD_ROOT}

%install
%make install-strip DESTDIR=${RPM_BUILD_ROOT}
# Ensure man pages are gzipped, regardless of brp-compress
if [ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ]; then
  find ${RPM_BUILD_ROOT}/%{_mandir} -name '*.[1-9]' | xargs gzip -9
fi
# Install the init script
%make -C etc install DESTDIR=${RPM_BUILD_ROOT}

# On some systems rpmbuild dislikes having an RPATH that points
# to a system directory.  Some versions of libtool get this right
# on their own, while others don't.
# So, we try to clean it up here if we have chrpath.
if chrpath --version >& /dev/null; then
chrpath -d ${RPM_BUILD_ROOT}/%{_bindir}/cr_checkpoint
chrpath -d ${RPM_BUILD_ROOT}/%{_bindir}/cr_restart
list=`make -C tests --no-print-directory echoval VARNAME=testsexec_PROGRAMS`
( cd ${RPM_BUILD_ROOT}/%{_libexecdir}/blcr-testsuite && chrpath -d $list )
fi

%post
if [ $1 = 1 ]; then
  /sbin/chkconfig --add blcr
fi
exit 0

%preun
if [ $1 = 0 ]; then
  /sbin/chkconfig --del blcr
fi
exit 0

%post %{modsubpkg}
/sbin/depmod -a -F %{sysmap}
if [ $1 = 2 ]; then
 # conditional reload on upgrade
 /etc/init.d/blcr reload >& /dev/null
fi
exit 0
%preun %{modsubpkg}
if [ $1 = 0 ]; then
 /etc/init.d/blcr stop >& /dev/null
fi
exit 0
%postun %{modsubpkg}
if [ $1 = 0 ]; then
 /sbin/depmod -a -F %{sysmap}
fi
exit 0

%post libs
/sbin/ldconfig
exit 0

%postun libs
/sbin/ldconfig
exit 0

%files
%defattr(-,root,root)
%doc LICENSE.txt
%doc COPYING
%doc NEWS
%doc doc/README
%doc doc/html
%doc %{_mandir}/man1/cr_checkpoint.1.*
%doc %{_mandir}/man1/cr_restart.1.*
%doc %{_mandir}/man1/cr_run.1.*
%{_bindir}/cr_checkpoint
#%{_bindir}/cr_info
%{_bindir}/cr_restart
%{_bindir}/cr_run
#%{_libexecdir}/vmadcheck
%{_sysconfdir}/init.d/blcr

%files libs
%defattr(-,root,root)
%doc LICENSE.txt
%doc COPYING.LIB
%doc NEWS
%{_libdir}/libcr.so.0
%{_libdir}/libcr.so.0.5.0
%{_libdir}/libcr.so.0
%{_libdir}/libcr_omit.so.0.5.0
%{_libdir}/libcr_omit.so.0
%{_libdir}/libcr_run.so.0.5.0
%{_libdir}/libcr_run.so.0

%files devel
%defattr(-,root,root)
%{_includedir}/blcr_common.h
%{_includedir}/blcr_errcodes.h
%{_includedir}/blcr_ioctl.h
%{_includedir}/blcr_proc.h
%{_includedir}/libcr.h
%{_includedir}/cr_xtreemos.h
# .la files
%{_libdir}/libcr.la
%{_libdir}/libcr_omit.la
%{_libdir}/libcr_run.la
# .so files
%{_libdir}/libcr.so
%{_libdir}/libcr_omit.so
%{_libdir}/libcr_run.so

%files %{modsubpkg}
%defattr(-,root,root)
%dir %{moduledir}
%{moduledir}/blcr.*o
%{moduledir}/blcr_imports.*o

%files testsuite
%defattr(-,root,root)
%{_libexecdir}/blcr-testsuite

